@@ -12,8 +12,10 @@ import pytest
 
 def run_pytest(*args):
     """ Run pytest and return its exit status. """
+
     pytest_args = [
         '--doctest-modules',
+        '--doctest-ignore-import-errors',
         '--ignore=setup.py',
     ] + list(args)
     errno = pytest.main(pytest_args)
@@ -60,7 +62,10 @@ def pytest_hook(args=()):
             fails += 1
             hook_return |= returncode
             if fails > continues:
-                sys.exit(returncode)
+                break
         os.chdir(restore_dir)
-    if hook_return:
+    if hook_return == 5:
+        echo.yellow('-> PyTest returned %d. No tests discovered?' % hook_return)
+        sys.exit(hook_return)
+    else:
         sys.exit(hook_return)
